@@ -49,24 +49,6 @@ static const char *keys [] =
     NULL
 };
 
-static const char *categories [] =
-{
-    "All",
-    "Recently Used",
-    "Core",
-    "Development",
-    "Office",
-    "Graphics",
-    "Network",
-    "AudioVideo",
-    "Game",
-    "Education",
-    "System",
-    "Filemanager",
-    "Utility",
-    NULL
-};
-
 static const char *i18ncategories [] =
 {
     N_("All"),
@@ -85,14 +67,4 @@ static const char *i18ncategories [] =
     NULL
 };
 
-/* Places where i can drop things */
-static GtkTargetEntry gte[] =
-{
-    {"DESKTOP_PATH_ENTRY", 0, 0},
-    {"text/plain", 0, 1},
-    {"application/x-desktop", 0, 2},
-    {"STRING", 0, 3},
-    {"UTF8_STRING", 0, 4}
-};
-
 #endif
